# [Zope-tests] OK : Bluebream / Python2.5.5 64bit linux

ccomb at free.fr ccomb at free.fr
Wed Feb 2 22:03:29 EST 2011

- Previous message: [Zope-tests] OK : Bluebream / Python2.6.5 64bit linux
- Next message: [Zope-tests] OK : Zope 3.4 Known Good Set / py2.5-64bit-linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Bluebream / Python2.5.5 64bit linux
    Build: http://buildbot.afpy.org/bluebream/builders/Python2.5.5%2064bit%20linux/builds/172

    Build Reason: The Nightly scheduler named 'nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://buildbot.afpy.org/bluebream/

- Previous message: [Zope-tests] OK : Bluebream / Python2.6.5 64bit linux
- Next message: [Zope-tests] OK : Zope 3.4 Known Good Set / py2.5-64bit-linux
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list